@@ -13,11 +13,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import json
+from unittest import mock
 
-import mock
+from oslo_serialization import jsonutils
 from oslo_utils import timeutils
-import six
 
 from barbicanclient import base
 from barbicanclient.tests import test_client
@@ -150,7 +149,7 @@ class WhenTestingContainers(test_client.BaseEntityResource):
                          self.responses.last_request.url)
 
         # Verify that correct information was sent in the call.
-        container_req = json.loads(self.responses.last_request.text)
+        container_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.container.name, container_req['name'])
         self.assertEqual(self.container.type, container_req['type'])
         self.assertEqual(self.container.generic_secret_refs_json,
@@ -172,7 +171,7 @@ class WhenTestingContainers(test_client.BaseEntityResource):
                          self.responses.last_request.url)
 
         # Verify that correct information was sent in the call.
-        container_req = json.loads(self.responses.last_request.text)
+        container_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.container.name, container_req['name'])
         self.assertEqual(self.container.type, container_req['type'])
         self.assertEqual(self.container.generic_secret_refs_json,
@@ -197,10 +196,10 @@ class WhenTestingContainers(test_client.BaseEntityResource):
                          self.responses.last_request.url)
 
         # Verify that correct information was sent in the call.
-        container_req = json.loads(self.responses.last_request.text)
+        container_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.container.name, container_req['name'])
         self.assertEqual('certificate', container_req['type'])
-        self.assertItemsEqual(self.container.certificate_secret_refs_json,
+        self.assertCountEqual(self.container.certificate_secret_refs_json,
                               container_req['secret_refs'])
 
     def test_should_store_certificate_via_constructor(self):
@@ -222,10 +221,10 @@ class WhenTestingContainers(test_client.BaseEntityResource):
                          self.responses.last_request.url)
 
         # Verify that correct information was sent in the call.
-        container_req = json.loads(self.responses.last_request.text)
+        container_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.container.name, container_req['name'])
         self.assertEqual('certificate', container_req['type'])
-        self.assertItemsEqual(self.container.certificate_secret_refs_json,
+        self.assertCountEqual(self.container.certificate_secret_refs_json,
                               container_req['secret_refs'])
 
     def test_should_store_rsa_via_attributes(self):
@@ -246,10 +245,10 @@ class WhenTestingContainers(test_client.BaseEntityResource):
                          self.responses.last_request.url)
 
         # Verify that correct information was sent in the call.
-        container_req = json.loads(self.responses.last_request.text)
+        container_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.container.name, container_req['name'])
         self.assertEqual('rsa', container_req['type'])
-        self.assertItemsEqual(self.container.rsa_secret_refs_json,
+        self.assertCountEqual(self.container.rsa_secret_refs_json,
                               container_req['secret_refs'])
 
     def test_should_store_rsa_via_constructor(self):
@@ -271,10 +270,10 @@ class WhenTestingContainers(test_client.BaseEntityResource):
                          self.responses.last_request.url)
 
         # Verify that correct information was sent in the call.
-        container_req = json.loads(self.responses.last_request.text)
+        container_req = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.container.name, container_req['name'])
         self.assertEqual('rsa', container_req['type'])
-        self.assertItemsEqual(self.container.rsa_secret_refs_json,
+        self.assertCountEqual(self.container.rsa_secret_refs_json,
                               container_req['secret_refs'])
 
     def test_should_get_secret_refs_when_created_using_secret_objects(self):
@@ -524,7 +523,7 @@ class WhenTestingContainers(test_client.BaseEntityResource):
 
         # Verify that the names of the secret_refs in the containers are None
         for container in containers_list:
-            for name in six.iterkeys(container._secret_refs):
+            for name in container._secret_refs.keys():
                 self.assertIsNone(name)
 
     def test_should_fail_get_invalid_container(self):
@@ -546,7 +545,7 @@ class WhenTestingContainers(test_client.BaseEntityResource):
         self.assertIsInstance(container, containers.Container)
         self.assertEqual(self.entity_href, container.container_ref)
 
-        body = json.loads(self.responses.last_request.text)
+        body = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.consumers_post_resource,
                          self.responses.last_request.url)
         self.assertEqual(self.container.consumer, body)
@@ -560,7 +559,7 @@ class WhenTestingContainers(test_client.BaseEntityResource):
             self.container.consumer.get('URL')
         )
 
-        body = json.loads(self.responses.last_request.text)
+        body = jsonutils.loads(self.responses.last_request.text)
         self.assertEqual(self.consumers_delete_resource,
                          self.responses.last_request.url)
         self.assertEqual(self.container.consumer, body)
