@@ -21,6 +21,7 @@ from oslo_utils import timeutils
 from barbicanclient import base
 from barbicanclient import exceptions
 from barbicanclient.tests import test_client
+from barbicanclient.tests.utils import mock_get_secret_for_client
 from barbicanclient.v1 import acls
 from barbicanclient.v1 import secrets
 
@@ -32,18 +33,24 @@ class SecretData(object):
         self.payload_content_type = 'text/plain'
         self.algorithm = 'AES'
         self.created = str(timeutils.utcnow())
+        self.consumer = {'service': 'service_test',
+                         'resource_type': 'type_test',
+                         'resource_id': 'id_test'}
 
         self.secret_dict = {'name': self.name,
                             'status': 'ACTIVE',
                             'algorithm': self.algorithm,
                             'created': self.created}
 
-    def get_dict(self, secret_ref=None, content_types_dict=None):
+    def get_dict(self, secret_ref=None, content_types_dict=None,
+                 consumers=None):
         secret = self.secret_dict
         if secret_ref:
             secret['secret_ref'] = secret_ref
         if content_types_dict:
             secret['content_types'] = content_types_dict
+        if consumers:
+            secret['consumers'] = consumers
         return secret
 
 
@@ -55,6 +62,9 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         self.secret = SecretData()
         self.manager = self.client.secrets
 
+        self.consumers_post_resource = self.entity_href + '/consumers/'
+        self.consumers_delete_resource = self.entity_href + '/consumers'
+
     def test_should_entity_str(self):
         secret_obj = self.manager.create(name=self.secret.name)
         self.assertIn(self.secret.name, str(secret_obj))
@@ -400,22 +410,26 @@ class WhenTestingSecrets(test_client.BaseEntityResource):
         bad_href = "http://badsite.com/" + self.entity_id
         self.test_should_decrypt(bad_href)
 
-    def test_should_delete_from_manager(self, secret_ref=None):
-        secret_ref = secret_ref or self.entity_href
-
+    def _mock_delete_secret(self):
         self.responses.delete(self.entity_href, status_code=204)
 
-        self.manager.delete(secret_ref=secret_ref)
+    def _delete_from_manager(self, secret_ref, force=False):
+        mock_get_secret_for_client(self.client)
+        self._mock_delete_secret()
+        self.manager.delete(secret_ref=secret_ref, force=force)
 
         # Verify the correct URL was used to make the call.
         self.assertEqual(self.entity_href, self.responses.last_request.url)
 
+    def test_should_delete_from_manager(self):
+        self._delete_from_manager(self.entity_href)
+
     def test_should_delete_from_manager_using_stripped_uuid(self):
         bad_href = "http://badsite.com/" + self.entity_id
-        self.test_should_delete_from_manager(bad_href)
+        self._delete_from_manager(secret_ref=bad_href)
 
     def test_should_delete_from_manager_using_only_uuid(self):
-        self.test_should_delete_from_manager(self.entity_id)
+        self._delete_from_manager(secret_ref=self.entity_id)
 
     def test_should_delete_from_object(self, secref_ref=None):
         secref_ref = secref_ref or self.entity_href
